package com.miaxis.app.school.dto;

import com.fasterxml.jackson.annotation.JsonFormat;
import com.miaxis.common.core.domain.BaseBusinessEntity;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;

import java.math.BigDecimal;
import java.util.Date;

/**
 * 驾校对象返回对象 SchoolInfoVO
 *
 * @author miaxis
 * @date 2020-12-24
 */
@Data
@ApiModel(value = "SchoolInfoVO", description = "驾校返回对象 SchoolInfoVO")
public class SchoolInfoVO extends BaseBusinessEntity {
    private static final long serialVersionUID = 1L;

    /** 驾校全国统一编号 */
    @ApiModelProperty(value = "驾校全国统一编号")
    private String inscode;

    /** 驾校名称 */
    @ApiModelProperty(value = "驾校名称")
    private String name;

    /** 驾校简称 */
    @ApiModelProperty(value = "驾校简称")
    private String sname;

    /** 驾校地址 */
    @ApiModelProperty(value = "驾校地址")
    private String address;

    /** 法人代表证件号码 */
    @ApiModelProperty(value = "法人代表证件号码")
    private String legalPersonIdNumber;

    /** 经营负责人 */
    @ApiModelProperty(value = "经营负责人")
    private String responsiblePerson;

    /** 法人代表 */
    @ApiModelProperty(value = "法人代表")
    private String legalPersonName;

    /** 行政区划名称 */
    @ApiModelProperty(value = "行政区划名称")
    private String areaName;

    /** 行政区划代码 */
    @ApiModelProperty(value = "行政区划代码")
    private String areaCode;

    /** 驾校电话 */
    @ApiModelProperty(value = "驾校电话")
    private String tel;

    /** 驾校微信号 */
    @ApiModelProperty(value = "驾校微信号")
    private String wechar;

    /** 注册日期 */
    @JsonFormat(pattern = "yyyy-MM-dd")
    @ApiModelProperty(value = "注册日期")
    private Date registrationDate;

    /** 经营许可证号 */
    @ApiModelProperty(value = "经营许可证号")
    private String licenseNumber;

    /** 经营许可证字 */
    @ApiModelProperty(value = "经营许可证字")
    private String licenseWord;

    /** 有效期起 */
    @JsonFormat(pattern = "yyyy-MM-dd")
    @ApiModelProperty(value = "有效期起")
    private Date licenseValidPeriodFrom;

    /** 有效期止 */
    @JsonFormat(pattern = "yyyy-MM-dd")
    @ApiModelProperty(value = "有效期止")
    private Date licenseValidPeriodEnd;

    /** 上年度信用等级 */
    @ApiModelProperty(value = "上年度信用等级")
    private String credibilityGrade;

    /** 当前信用得分 */
    @ApiModelProperty(value = "当前信用得分")
    private String credibilityScore;

    /** 业户车辆总数 */
    @ApiModelProperty(value = "业户车辆总数")
    private Long vehicleSum;

    /** 注册资金（单位:万元） */
    @ApiModelProperty(value = "注册资金（单位:万元）")
    private Long regcapital;

    /** 工商执照号 */
    @ApiModelProperty(value = "工商执照号")
    private String bizlicense;

    /** 原始gps经度，单位为1*10-6 度 */
    @ApiModelProperty(value = "原始gps经度，单位为1*10-6 度")
    private BigDecimal poiLon;

    /** 原始gps纬度，单位为1*10-6 度 */
    @ApiModelProperty(value = "原始gps纬度，单位为1*10-6 度")
    private BigDecimal poiLat;

    /** 逻辑删除标识（1：是；0：否） */
    @ApiModelProperty(value = "逻辑删除标识（1：是；0：否）")
    private Long removed;

    /** 初次领证日期 */
    @JsonFormat(pattern = "yyyy-MM-dd")
    @ApiModelProperty(value = "初次领证日期")
    private Date initialReceiptDate;

    /** 业户经营状态 */
    @ApiModelProperty(value = "业户经营状态")
    private String businessStatusName;

    /** 培训车型 */
    @ApiModelProperty(value = "培训车型")
    private String pxcx;

    /** 学员口碑 */
    @ApiModelProperty(value = "学员口碑")
    private String starts;

    /** 当前距离 */
    @ApiModelProperty(value = "当前距离")
    private String distance;

}
